==> overlapping_2.1.tgz: overlapping/NEWS.md <==
# overlapping 2.1 

### Bug fixes 

- fixed a bug in function `boot.overlap()` - thanks to TCM.  

# overlapping 2.0   

### Features 

- added function `ovmult()` for computing also multiple overlapping.  
- updated function `overlap()`.  
- updated function `final.plot()`.  

# overlapping 1.8  

### Bug fixes  

- fixed a bug in function `overlap()`.  

### Features  

- updated news file format.  

# overlapping 1.7  

### Features  

- changed function `boot.overlap()` - thanks to Jeremy Vollen.  
- fixed a warning in the function `final.plot()` and changed panel plots titles.  
- changed output in function `overlap()`.  

# overlapping 1.6  

### Features  

- changed function `final.plot()` for fixing an error with `grep()`.  

# overlapping 1.5.4  

### Bug fixes   

- fixed a bug in function `boot.overlap()`.   

# overlapping 1.5.3  

### Features  

- added function `boot.overlap()`.  

# overlapping 1.5.2   

### Features  

- updated `cutnumeric()`.  
- updated `overlap()`.   
- added automated test.   

# overlapping 1.5   

### Bug fixes    

- fixed a bug in function `final.plot()`.  

# overlapping 1.4  

### Bug fixes   

- fixed a bug producing warnings in function `overlap()`.  

### Features  

- changed package for graphics from `lattice` to `ggplot2`.  

# overlapping 1.3  

### Bug fixes    

- fixed a bug error in function `final.plot()`.  

### Features  

- updated output list in function `overlap()`.  

# overlapping 1.2  
  
### Features    

- changed Depends: R (>= 3.2.0).  

# overlapping 1.1  

### Bug fixes   

- fixed a bug error in function `final.plot()`.

==> overlapping_2.4.tgz: overlapping/NEWS.md <==
# overlapping 2.4 

### Features

- added paired permutation test
- corrected `perm.test()` formula 

# overlapping 2.3 

### Features

- fixed a bug in  function `boot.overlap()`    

# overlapping 2.2 

### Features

- added function `perm.test()` for performing permutation test   

# overlapping 2.1 

### Bug fixes 

- fixed a bug in function `boot.overlap()` - thanks to TCM. 


# overlapping 2.0   

### Features 

- added function `ovmult()` for computing also multiple overlapping.  
- updated function `overlap()`.  
- updated function `final.plot()`.  

# overlapping 1.8  

### Bug fixes  

- fixed a bug in function `overlap()`.  

### Features  

- updated news file format.  

# overlapping 1.7  

### Features  

- changed function `boot.overlap()` - thanks to Jeremy Vollen.  
- fixed a warning in the function `final.plot()` and changed panel plots titles.  
- changed output in function `overlap()`.  

# overlapping 1.6  

### Features  

- changed function `final.plot()` for fixing an error with `grep()`.  

# overlapping 1.5.4  

### Bug fixes   

- fixed a bug in function `boot.overlap()`.   

# overlapping 1.5.3  

### Features  

- added function `boot.overlap()`.  

# overlapping 1.5.2   

### Features  

- updated `cutnumeric()`.  
- updated `overlap()`.   
- added automated test.   

# overlapping 1.5   

### Bug fixes    

- fixed a bug in function `final.plot()`.  

# overlapping 1.4  

### Bug fixes   

- fixed a bug producing warnings in function `overlap()`.  

### Features  

- changed package for graphics from `lattice` to `ggplot2`.  

# overlapping 1.3  

### Bug fixes    

- fixed a bug error in function `final.plot()`.  

### Features  

- updated output list in function `overlap()`.  

# overlapping 1.2  
  
### Features    

- changed Depends: R (>= 3.2.0).  

# overlapping 1.1  

### Bug fixes   

- fixed a bug error in function `final.plot()`.
